@@ -1026,15 +1026,15 @@ namespace AuthN {
       /// In case of error negative status is returned.
       AuthN::Status Connect(const std::string& host, int port);
 
-      /// Wait and accept connection at specified TCP/IP port and interface.
-      ///  If interface is empty then socket is bound to all available interfaces.
+      /// Wait and accept connection at specified TCP/IP port and host interface.
+      /// If host is empty then socket is bound to all available interfaces.
       /// If port is set to 0 then socket is bound to arbitrary port.
       /// Returned object represents established connection and has same Context
       /// and Validator associated. This IO object keeps listening on specified
       /// port and interface even after method exits.
       /// In case of error invalid object is returned. Error description can
       /// be obtained by using GetStatus() method.
-      AuthN::IO& Accept(const std::string& interface, int port);
+      AuthN::IO& Accept(const std::string& host, int port);
 
       /// Returns true if object is valid.
       virtual operator bool(void) const;
