@@ -14,24 +14,16 @@
 
 // TODO: remove all formats not needed for canl. Make parsing simpler.
 
-/*
 #ifndef HAVE_TIMEGM
 time_t timegm(struct tm *tm) {
   bool found;
-  std::string tz = Arc::GetEnv("TZ", found);
-  Arc::SetEnv("TZ", "UTC");
   tzset();
   tm->tm_isdst = -1;
   time_t ret = mktime(tm);
-  if (found)
-    Arc::SetEnv("TZ", tz);
-  else
-    Arc::UnsetEnv("TZ");
   tzset();
   return ret;
 }
 #endif
-*/
 
 bool stringto(const std::string& s, uint64_t& t) {
   t = 0;
