@@ -3,7 +3,19 @@
 #endif
 
 #include <sys/types.h>
+
+#ifdef WIN32
+#include <windows.h>
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#undef USE_WINSOCK
+#define USE_WINSOCK 2
+#include <io.h>
+#include <winsock2.h>
+#else
 #include <sys/socket.h>
+#endif
+
 #include <sys/time.h>
 #include <unistd.h>
 #include <errno.h>
@@ -25,7 +37,6 @@ static int ssl_no_passphrase_callback(char*, int, int, void*) {
 
 static int ssl_verify_callback(int ok,X509_STORE_CTX *sctx) {
   if(!ok) {
-    int err = X509_STORE_CTX_get_error(sctx);
     X509_STORE_CTX_set_error(sctx,X509_V_OK); 
     //SSL* ssl = (SSL*)X509_STORE_CTX_get_ex_data(sctx,SSL_get_ex_data_X509_STORE_CTX_idx());
     //if(ssl) SSL_set_verify_result(ssl,X509_V_OK);
@@ -213,8 +224,6 @@ IONetwork::~IONetwork(void) {
 AuthN::Status IONetwork::Connect(const std::string& host, int port) {
   //int err = SSL_ERROR_NONE;
   SSL* ssl = NULL;
-  X509* cert = NULL;
-  STACK_OF(X509)* chain = NULL;
   
   try {
 
@@ -302,10 +311,8 @@ AuthN::Status IONetwork::Connect(const std::string& host, int port) {
   };
 }
 
-AuthN::IO& IONetwork::Accept(const std::string& interface, int port) {
+AuthN::IO& IONetwork::Accept(const std::string& host, int port) {
   SSL *ssl;
-  X509* cert = NULL;
-  STACK_OF(X509)* chain = NULL;
   BIO* conn = NULL;
   BIO* sbio = NULL;
 
@@ -337,7 +344,7 @@ AuthN::IO& IONetwork::Accept(const std::string& interface, int port) {
 #endif
 
 
-    bio_ = BIO_new_accept((char*)((interface.empty()?"*":interface)+":"+tostring(port)).c_str());
+    bio_ = BIO_new_accept((char*)((host.empty()?"*":host)+":"+tostring(port)).c_str());
     if(!bio_) throw Status(-1);
     if(BIO_do_accept(bio_) <= 0) throw Status(-1);
   };
@@ -485,8 +492,6 @@ IOSocket::~IOSocket(void) {
 AuthN::Status IOSocket::Connect(int socket) {
   //int err = SSL_ERROR_NONE;
   SSL* ssl = NULL;
-  X509* cert = NULL;
-  STACK_OF(X509)* chain = NULL;
   
   try {
 
@@ -551,8 +556,6 @@ AuthN::Status IOSocket::Connect(int socket) {
 
 AuthN::Status IOSocket::Accept(int socket) {
   SSL *ssl;
-  X509* cert = NULL;
-  STACK_OF(X509)* chain = NULL;
   BIO* conn = NULL;
 
   try {
