@@ -306,10 +306,9 @@ namespace NSS {
     PRArenaPool *arena = NULL;
     SECStatus rv = SECSuccess;
     SECOidData* oid = NULL;
-    SECItem policy_item;
+    //SECItem policy_item;
     std::string pl_lang;
     SECOidTag tag;
-    void* mark;
 
     pl_lang = policylang;
     if(pl_lang == "Any language") tag = tag_anylang;
@@ -320,7 +319,7 @@ namespace NSS {
 
     if((policy != NULL) && (pathlen != -1)) {
       ProxyCertInfo1* proxy_certinfo = NULL;
-      ProxyPolicy1* proxy_policy = NULL;
+     // ProxyPolicy1* proxy_policy = NULL;
     
       arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
       if (!arena ) {
@@ -346,7 +345,7 @@ namespace NSS {
     }
     else if((policy == NULL) && (pathlen != -1)) {
       ProxyCertInfo2* proxy_certinfo = NULL;
-      ProxyPolicy2* proxy_policy = NULL;
+      //ProxyPolicy2* proxy_policy = NULL;
 
       arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
       if (!arena ) {
@@ -370,7 +369,7 @@ namespace NSS {
     }
     else if((policy != NULL) && (pathlen == -1)) {
       ProxyCertInfo3* proxy_certinfo = NULL;
-      ProxyPolicy3* proxy_policy = NULL;
+      //ProxyPolicy3* proxy_policy = NULL;
 
       arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
       if (!arena ) {
@@ -393,7 +392,7 @@ namespace NSS {
     }
     else {
       ProxyCertInfo4* proxy_certinfo = NULL;
-      ProxyPolicy4* proxy_policy = NULL;
+      //ProxyPolicy4* proxy_policy = NULL;
 
       arena = PORT_NewArena(DER_DEFAULT_CHUNKSIZE);
       if (!arena ) {
@@ -422,11 +421,11 @@ error:
   // Add a binary into extension, specific for the VOMS AC sequence
   SECStatus AddVOMSACSeqExtension(void* extHandle, char* vomsacseq, int length) {
     SECStatus rv = SECFailure;
-    SECOidData* oid = NULL;
+    //SECOidData* oid = NULL;
     SECOidTag tag;
 
     tag = tag_vomsacseq;
-    oid = SECOID_FindOIDByTag(tag);
+    //oid = SECOID_FindOIDByTag(tag);
 
     if(vomsacseq != NULL) {
       SECItem encodedValue;
@@ -486,7 +485,6 @@ error:
 
   SECStatus GetExtension(const std::string& cert_name,
       const std::string& oid_str, AuthN::Credentials::Extension& extension) {
-    SECStatus rv;
     CERTCertificate* cert = NULL;
     CERTCertDBHandle* handle;
     CERTCertExtension* ext = NULL;
@@ -514,7 +512,6 @@ error:
 
   SECStatus GetExtension(const std::string& cert_name, int pos,
       AuthN::Credentials::Extension& extension) {
-    SECStatus rv;
     CERTCertificate* cert = NULL;
     CERTCertDBHandle* handle;
     CERTCertExtension* ext = NULL;
@@ -1253,7 +1250,8 @@ error:
     }
     for (i=0; i < 8; i++) {
       if ( (0x80 >> i) & NS_Type) {
-        out.append((const char*)(found ? ',' : '<')).append(nsTypeBits[i]);
+        out += (found ? ',' : '<');
+        out.append(nsTypeBits[i]);
         found = 1;
       }
     }
@@ -1714,7 +1712,6 @@ error:
     SECItem* ext_id_item = NULL;
     SECItem* ext_critical_item = NULL;
     SECOidTag tag;
-    SECStatus rv = SECFailure;
     int level = 0;
 
     ext_value_item = &ext->value;
