@@ -147,7 +147,6 @@ namespace OpenSSL {
   Status ssl_stapling_init_CertStatusContext(Context* logctx, SSL_CTX* sslctx, X509* cert, 
       const std::string& cache_file, long cache_interval, const std::string& resp_url) {
     CertStatusContext* cert_stat_ctx = NULL;
-    OCSP_CERTID* cert_id = NULL;
     std::string responder_url;
     AuthN::Utils::Cache* cache = NULL;
     Status stat;
@@ -339,8 +338,10 @@ namespace OpenSSL {
  
   static Status ocspreq2string(OCSP_REQUEST* req, std::string& reqstr) {
     unsigned char* req_buf = NULL;
+/*
     unsigned char* str;
     unsigned int str_len;
+*/
     Status stat;
 
     if(!req) return Status(-1, "OCSP request is empty");
@@ -388,8 +389,10 @@ namespace OpenSSL {
 
   static Status ocspresp2string(OCSP_RESPONSE* resp, std::string& respstr) {
     unsigned char* resp_buf = NULL;
+/*
     unsigned char* str;
     unsigned int str_len;
+*/
     Status stat;
     
     if(!resp) return Status(-1, "OCSP response is empty");
@@ -787,9 +790,7 @@ namespace OpenSSL {
     std::string ocsp_resp_out;
     AutoBIO ocsp_resp_out_bio(BIO_new(BIO_s_mem()));
     OCSP_CERTID* id = NULL;
-    STACK_OF(X509_EXTENSION) *exts;
     Status stat;
-    int i;
 
     if(!req_) return Status(-1, "OCSP request is empty, call MakeOCSPRequest at first");
 
@@ -831,9 +832,11 @@ namespace OpenSSL {
     if (id) OCSP_CERTID_free(id);
     return last_error_;
 
+/*
     err:
     last_error_ = Status(-2, "Fatal error happens"); 
     goto done;
+*/
   }
 
 /*
@@ -875,15 +878,12 @@ namespace OpenSSL {
   // valid for the openssl versions on which tls ext data
   // is supported. 
   int ocsp_stapling_server_callback(SSL* ssl, void* arg) {
-    int ret = SSL_TLSEXT_ERR_NOACK;
     CertStatusContext* csctx = NULL;
     Context* context = NULL;
     AuthN::Utils::Cache* cache = NULL;
-    OCSP_CERTID* cert_id = NULL;
     X509* cert = NULL;
     std::string responder_url;
     std::string req_str, resp_str;
-    OCSPContext::CertStatus cert_status;
     Status stat;
 
     stat =  ssl_stapling_get_CertStatusContext(ssl, &csctx);
