@@ -589,7 +589,7 @@ namespace OpenSSL {
     }
     else if(req) {
       req_exts = x509_req_get_extensions(req);
-      if(!req_exts) keyusages;
+      // if(!req_exts) keyusages;
       index = X509v3_get_ext_by_NID(req_exts, NID_ext_key_usage, -1);
       if(index != -1) {
         ex = X509v3_get_ext(req_exts, index);
@@ -820,7 +820,6 @@ namespace OpenSSL {
             nid = OBJ_obj2nid(X509_EXTENSION_get_object(x509_ext));
             if(nid == NID_proxyCertInfo) {
               std::string oid;
-              bool crit = false;
               std::string ext_val;
               if(!retrieve_extension(*logctx, x509_ext, policy)) {
                 logctx->Log(Context::LogError, "Failed to retrieve policy extension");
@@ -892,7 +891,6 @@ namespace OpenSSL {
 
       Status X509ExtUtil::get_extension(const std::string& name, Credentials::Extension& ext) const {
         std::string oid;
-        bool crit = false;
         std::string ext_val;
         X509_EXTENSION* ex = NULL;
 
@@ -975,8 +973,6 @@ namespace OpenSSL {
           if(nid == NID_undef) nid = OBJ_sn2nid((char*)(ext.oid.c_str()));
           if(nid == NID_undef) nid = OBJ_ln2nid((char*)(ext.oid.c_str()));
           if(nid != NID_undef) {
-            unsigned char* ext_der;
-            int ext_len;
             ASN1_OCTET_STRING *ext_oct;
             ext_oct = M_ASN1_OCTET_STRING_new();
             ext_oct->data = (unsigned char*)(ext.value.c_str());
@@ -1135,12 +1131,12 @@ namespace OpenSSL {
      */
 
     std::string oid_name;
-    bool critical = false;
+    //bool critical = false;
     std::string::size_type pos = name.find(":");
     if(pos != std::string::npos) {
       oid_name = name.substr(0, pos);
       std::string crit_str = name.substr(pos+1);
-      if(crit_str.find("critical") != std::string::npos) critical = true;
+      //if(crit_str.find("critical") != std::string::npos) critical = true;
     }
     else oid_name = name;
     trim_blank(oid_name);
@@ -1154,7 +1150,7 @@ namespace OpenSSL {
       // only one item should be available in the attribute list
       std::string value = *attrs.begin();
       value = upper_string(value);
-      bool critical=false, ca=false;
+      bool ca=false;
       int pathlen=-1;
 
       pos = value.find("ca:");
@@ -1219,7 +1215,6 @@ namespace OpenSSL {
   Status X509ExtUtil::get_attributes(const std::string& name, std::list<std::string>& attrs) const {
     // 1. Suppose the attribute is a extension, which means the
     // name argument can be matched into an extension name
-    bool crit = false;
     std::string ext_val;
     int nid;
     nid = OBJ_txt2nid(name.c_str());
