@@ -42,8 +42,8 @@ private:
   std::string opensslcnf;
   std::string certfile;
   std::string keyfile;
-  std::string cadir;
   std::string crlfile;
+  std::string cadir;
   std::string trusted_cadir;
   std::string eec_subject;
   std::string ocsp_responder_uri;
@@ -160,7 +160,6 @@ void CredentialsTest::TestCredentialsRequest() {
   credreq.AddAttributes(attr_name, ext_attr_value);
 
   // Get private and public key
-  bool enc = false;
   std::string privk_str, pubk_str;
   credreq.GetPrivateKey(privk_str);
   credreq.GetPublicKey(pubk_str);
@@ -552,8 +551,6 @@ void CredentialsTest::tearDown() {
 
 void CredentialsTest::launch_ocsp_responder() {
   //pid_t pid;
-  int status;
-  bool res;
   char *argv[16];
   std::string cafile = cadir + "/cacert.pem";
   std::string cakey = cadir + "/cakey.pem";
