@@ -63,7 +63,6 @@ void OCSPStaplingTest::TestOCSPStapling() {
 
   // Setup the server which will accept request from client
   pid_t pid;
-  int status;
   char *argv[6];
   char port_str[8];
   sprintf(port_str, "%d", port);
@@ -131,8 +130,6 @@ void OCSPStaplingTest::TestOCSPStapling() {
 }
 
 void OCSPStaplingTest::launch_ocsp_responder() {
-  int status;
-  bool res;
   char *argv[16];
   std::string cafile = cadir + "/cacert.pem";
   std::string cakey = cadir + "/cakey.pem";
